==> common-1.3.0.22-sources.jar: cn/gtmap/gtc/workflow/enums/manage/ProcQuerykey.java <==
package cn.gtmap.gtc.workflow.enums.manage;

public enum ProcQuerykey {

    /**
     * 流程实例ID相等条件
     */
    PROCINSID_EQ("procInsId_eq"),
    /**
     *流程实例名称相等条件
     */
    PROCESSINSTANCENAME_EQ("processInstanceName_eq"),
    /**
     *启动流程的开始节点相等条件
     */
    STARTACTIVITYID_EQ("startActivityId_eq"),
    /**
     *流程启动人相当于 人员code 相等条件
     */
    STARTUSERID_EQ("startUserId_eq"),
    /**
     *流程开始时间相等条件
     */
    STARTTIME_EQ("startTime_eq"),
    /**
     *流程开始时间相等条件
     */
    ENDTIME_EQ("endTime_eq"),
    /**
     *流程删除原因相等条件
     */
    DELETEREASON_EQ("deleteReason_eq"),
    /**
     *流程定义id相等条件
     */
    PROCDEFID_EQ("procDefId_eq"),
    /**
     *流程定义唯一标识符相等条件
     */
    PROCDEFKEY_EQ("procDefKey_eq"),
    /**
     *流程到期期限类型相等条件
     */
    PROCDUETYPE_EQ("procDueType_eq"),
    /**
     *流程到期期限相等条件
     */
    PROCDUELIMIT_EQ("procDueLimit_eq"),
    /**
     *流程到期时间相等条件
     */
    PROCDUETIME_EQ("procDueTime_eq"),
    /**
     *流程启动人员部门相等条件
     */
    STARTUSERDEP_EQ("startUserDep_eq"),
    /**
     *流程启动人员中文名称相等条件
     */
    STARTUSERNAME_EQ("startUserName_eq"),
    /**
     *流程超期任务数相等条件
     */
    PROCTIMEOUTCOUNT_EQ("procTimeoutCount_eq"),
    /**
     *流程超期状态相等条件
     */
    PROCTIMEOUTSTATUS_EQ("procTimeoutStatus_eq"),
    /**
     *流程状态相等条件
     */
    PROCSTATUS_EQ("procStatus_eq"),
    /**
     *流程类别相等条件
     */
    CATEGORY_EQ("category_eq"),

    /**
     *项目ID的相等条件
     */
    PROJECTID_EQ ("projectId_eq"),

    /**
     *项目的名称的相等条件
     */
    PROJECTNAME_EQ  ("projectName_eq"),

    /**
     *自定义的文本1的相等条件
     */
    TEXT1_EQ  ("text1_eq"),

    /**
     *自定义的文本2的相等条件
     */
    TEXT2_EQ ("text2_eq"),

    /**
     *自定义的文本3的相等条件
     */
    TEXT3_EQ ("text3_eq"),

    /**
     *自定义的文本4的相等条件
     */
    TEXT4_EQ ("text4_eq"),

    /**
     *自定义的文本5的相等条件
     */
    TEXT5_EQ ("text5_eq"),

    /**
     *自定义的文本6的相等条件
     */
    TEXT6_EQ ("text6_eq"),

    /**
     *自定义的文本7的相等条件
     */
    TEXT7_EQ ("text7_eq"),

    /**
     *自定义的文本8的相等条件
     */
    TEXT8_EQ ("text8_eq"),

    /**
     *自定义的文本9的相等条件
     */
    TEXT9_EQ ("text9_eq"),

    /**
     *自定义的int1的相等条件
     */
    NIM1_EQ ("num1_eq"),

    /**
     *自定义的int2的相等条件
     */
    NUM2_EQ ("num2_eq"),

    /**
     *自定义的文日期1的相等条件
     */
    DATE1_EQ ("date1_eq"),

    /**
     *自定义的日期2的相等条件
     */
    DATE2_EQ("date2_eq"),

    /**
     * 流程实例名称相似查询
     */
    PROCESSINSTANCENAME_LIKE("processInstanceName_like"),

    /**
     * 启动流程的人员名称相似查询
     */
    STARTUSERNAME_LIKE("startUserName_like"),

    /**
     *项目名称的相似查询
     */
    PROJECTNAME_LIKE ("projectName_like"),

    /**
     *自定义文本1相似查询
     */
    TEXT1_LIKE ("text1_like"),

    /**
     *自定义文本2相似查询
     */
    TEXT2_LIKE ("text2_like"),

    /**
     *自定义文本3相似查询
     */
    TEXT3_LIKE ("text3_like"),

    /**
     *自定义文本4相似查询
     */
    TEXT4_LIKE ("text4_like"),

    /**
     *自定义文本5相似查询
     */
    TEXT5_LIKE ("text5_like"),

    /**
     *自定义文本6相似查询
     */
    TEXT6_LIKE ("text6_like"),

    /**
     *自定义文本7相似查询
     */
    TEXT7_LIKE ("text7_like"),

    /**
     *自定义文本8相似查询
     */
    TEXT8_LIKE ("text8_like"),

    /**
     *自定义文本9相似查询
     */
    TEXT9_LIKE ("text9_like"),

    /**
     *开始时间的不等于查询
     */
    STARTTIME_NEQ ("startTime_neq "),

    /**
     *开始时间的大于查询
     */
    STARTTIME_GT  ("startTime_gt"),

    /**
     *开始时间的大于等于询
     */
    STARTTIME_EGT  ("startTime_egt"),

    /**
     *开始时间的小于
     */
    STARTTIME_LT ("startTime_lt"),

    /**
     *开始时间的小于等于
     */
    STARTTIME_ELT ("startTime_elt"),

    /**
     *结束时间的不等于查询
     */
    ENDTIME_NEQ  ("endTime_neq "),

    /**
     *结束时间的大于查询
     */
    ENDTIME_GT  ("endTime_gt"),

    /**
     *结束时间的大于等于询
     */
    ENDTIME_EGT  ("endTime_egt"),

    /**
     *结束时间的小于
     */
    ENDTIME_LT ("endTime_lt"),

    /**
     *结束时间的小于等于
     */
    ENDTIME_ELT ("endTime_elt"),

    /**
     *自定义时间的不等于
     */
    DATE1_NEQ ("date1_neq"),

    /**
     *自定义时间的大于
     */
    DATE1_GT ("date1_gt"),

    /**
     *自定义时间的大于等于
     */
    DATE1_EGT ("date1_egt"),

    /**
     *自定义时间的小于
     */
    DATE1_LT ("date1_lt"),

    /**
     *自定义时间的小于等于
     */
    DATE1_ELT ("date1_elt"),

    /**
     *自定义时间的不等于
     */
    DATE2_NEQ ("date2_neq"),

    /**
     *自定义时间的大于
     */
    DATE2_GT ("date2_gt"),

    /**
     *自定义时间的大于等于
     */
    DATE2_EGT ("date2_egt"),

    /**
     *自定义时间的小于
     */
    DATE2_LT ("date2_lt"),

    /**
     *自定义时间的小于等于
     */
    DATE2_ELT ("date2_elt"),

    /**
     *开始时间的降序
     */
    STARTTIME_DESC ("startTime_desc"),

    /**
     *开始时间升序
     */
    STARTTIME_ASC ("startTime_asc");

    private final String value;

    ProcQuerykey(String v){
        value = v;
    }

    public String value() {
        return value;
    }
}

==> common-1.3.0.33-sources.jar: cn/gtmap/gtc/workflow/enums/manage/ProcQuerykey.java <==
package cn.gtmap.gtc.workflow.enums.manage;

public enum ProcQuerykey {

    /**
     * 受理节点归属部门ID相等条件
     */
    START_USER_DEP_ID_EQ("startUserDepId_eq"),
    /**
     * 流程实例ID相等条件
     */
    PROCINSID_EQ("procInsId_eq"),
    /**
     *流程实例名称相等条件
     */
    PROCESSINSTANCENAME_EQ("processInstanceName_eq"),
    /**
     *启动流程的开始节点相等条件
     */
    STARTACTIVITYID_EQ("startActivityId_eq"),
    /**
     *流程启动人相当于 人员code 相等条件
     */
    STARTUSERID_EQ("startUserId_eq"),
    /**
     *流程开始时间相等条件
     */
    STARTTIME_EQ("startTime_eq"),
    /**
     *流程开始时间相等条件
     */
    ENDTIME_EQ("endTime_eq"),
    /**
     *流程删除原因相等条件
     */
    DELETEREASON_EQ("deleteReason_eq"),
    /**
     *流程定义id相等条件
     */
    PROCDEFID_EQ("procDefId_eq"),
    /**
     *流程定义唯一标识符相等条件
     */
    PROCDEFKEY_EQ("procDefKey_eq"),
    /**
     *流程到期期限类型相等条件
     */
    PROCDUETYPE_EQ("procDueType_eq"),
    /**
     *流程到期期限相等条件
     */
    PROCDUELIMIT_EQ("procDueLimit_eq"),
    /**
     *流程到期时间相等条件
     */
    PROCDUETIME_EQ("procDueTime_eq"),
//    /**
//     *流程启动人员部门相等条件
//     */
//    STARTUSERDEP_EQ("startUserDep_eq"),
    /**
     *流程启动人员中文名称相等条件
     */
    STARTUSERNAME_EQ("startUserName_eq"),
    /**
     *流程超期任务数相等条件
     */
    PROCTIMEOUTCOUNT_EQ("procTimeoutCount_eq"),
    /**
     *流程超期状态相等条件
     */
    PROCTIMEOUTSTATUS_EQ("procTimeoutStatus_eq"),
    /**
     *流程状态相等条件
     */
    PROCSTATUS_EQ("procStatus_eq"),
    /**
     *流程类别相等条件
     */
    CATEGORY_EQ("category_eq"),

    /**
     *项目ID的相等条件
     */
    PROJECTID_EQ ("projectId_eq"),

    /**
     *项目的名称的相等条件
     */
    PROJECTNAME_EQ  ("projectName_eq"),

    /**
     *自定义的文本1的相等条件
     */
    TEXT1_EQ  ("text1_eq"),

    /**
     *自定义的文本2的相等条件
     */
    TEXT2_EQ ("text2_eq"),

    /**
     *自定义的文本3的相等条件
     */
    TEXT3_EQ ("text3_eq"),

    /**
     *自定义的文本4的相等条件
     */
    TEXT4_EQ ("text4_eq"),

    /**
     *自定义的文本5的相等条件
     */
    TEXT5_EQ ("text5_eq"),

    /**
     *自定义的文本6的相等条件
     */
    TEXT6_EQ ("text6_eq"),

    /**
     *自定义的文本7的相等条件
     */
    TEXT7_EQ ("text7_eq"),

    /**
     *自定义的文本8的相等条件
     */
    TEXT8_EQ ("text8_eq"),

    /**
     *自定义的文本9的相等条件
     */
    TEXT9_EQ ("text9_eq"),

    /**
     *自定义的int1的相等条件
     */
    NIM1_EQ ("num1_eq"),

    /**
     *自定义的int2的相等条件
     */
    NUM2_EQ ("num2_eq"),

    /**
     *自定义的文日期1的相等条件
     */
    DATE1_EQ ("date1_eq"),

    /**
     *自定义的日期2的相等条件
     */
    DATE2_EQ("date2_eq"),

    /**
     * 流程实例名称相似查询
     */
    PROCESSINSTANCENAME_LIKE("processInstanceName_like"),

    /**
     * 启动流程的人员名称相似查询
     */
    STARTUSERNAME_LIKE("startUserName_like"),

    /**
     *项目名称的相似查询
     */
    PROJECTNAME_LIKE ("projectName_like"),

    /**
     *自定义文本1相似查询
     */
    TEXT1_LIKE ("text1_like"),

    /**
     *自定义文本2相似查询
     */
    TEXT2_LIKE ("text2_like"),

    /**
     *自定义文本3相似查询
     */
    TEXT3_LIKE ("text3_like"),

    /**
     *自定义文本4相似查询
     */
    TEXT4_LIKE ("text4_like"),

    /**
     *自定义文本5相似查询
     */
    TEXT5_LIKE ("text5_like"),

    /**
     *自定义文本6相似查询
     */
    TEXT6_LIKE ("text6_like"),

    /**
     *自定义文本7相似查询
     */
    TEXT7_LIKE ("text7_like"),

    /**
     *自定义文本8相似查询
     */
    TEXT8_LIKE ("text8_like"),

    /**
     *自定义文本9相似查询
     */
    TEXT9_LIKE ("text9_like"),

    /**
     *开始时间的不等于查询
     */
    STARTTIME_NEQ ("startTime_neq "),

    /**
     *开始时间的大于查询
     */
    STARTTIME_GT  ("startTime_gt"),

    /**
     *开始时间的大于等于询
     */
    STARTTIME_EGT  ("startTime_egt"),

    /**
     *开始时间的小于
     */
    STARTTIME_LT ("startTime_lt"),

    /**
     *开始时间的小于等于
     */
    STARTTIME_ELT ("startTime_elt"),

    /**
     *结束时间的不等于查询
     */
    ENDTIME_NEQ  ("endTime_neq "),

    /**
     *结束时间的大于查询
     */
    ENDTIME_GT  ("endTime_gt"),

    /**
     *结束时间的大于等于询
     */
    ENDTIME_EGT  ("endTime_egt"),

    /**
     *结束时间的小于
     */
    ENDTIME_LT ("endTime_lt"),

    /**
     *结束时间的小于等于
     */
    ENDTIME_ELT ("endTime_elt"),

    /**
     *自定义时间的不等于
     */
    DATE1_NEQ ("date1_neq"),

    /**
     *自定义时间的大于
     */
    DATE1_GT ("date1_gt"),

    /**
     *自定义时间的大于等于
     */
    DATE1_EGT ("date1_egt"),

    /**
     *自定义时间的小于
     */
    DATE1_LT ("date1_lt"),

    /**
     *自定义时间的小于等于
     */
    DATE1_ELT ("date1_elt"),

    /**
     *自定义时间的不等于
     */
    DATE2_NEQ ("date2_neq"),

    /**
     *自定义时间的大于
     */
    DATE2_GT ("date2_gt"),

    /**
     *自定义时间的大于等于
     */
    DATE2_EGT ("date2_egt"),

    /**
     *自定义时间的小于
     */
    DATE2_LT ("date2_lt"),

    /**
     *自定义时间的小于等于
     */
    DATE2_ELT ("date2_elt"),

    /**
     *开始时间的降序
     */
    STARTTIME_DESC ("startTime_desc"),

    /**
     *开始时间升序
     */
    STARTTIME_ASC ("startTime_asc");

    private final String value;

    ProcQuerykey(String v){
        value = v;
    }

    public String value() {
        return value;
    }
}
